@@ -1,6 +1,7 @@
 import requests
 from cannerflow.csv_wrapper import CsvWrapper
 from cannerflow.json_wrapper import JsonWrapper
+from cannerflow.image_wrapper import ImageWrapper
 __all__ = ["File"]
 
 class File(object):
@@ -79,4 +80,8 @@ class File(object):
         content = self.get_content(absolutePath)
         jsonWrapper = JsonWrapper(content=content)
         return jsonWrapper
+    def get_image_wrapper(self, absolutePath):
+        content = self.get_content(absolutePath)
+        imageWrapper = ImageWrapper(content=content)
+        return imageWrapper
 
